<?php

namespace Drupal\opensign\App;

use Drupal\Core\Session\AccountInterface;
use GuzzleHttp\Client;
use GuzzleHttp\Exception\RequestException;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RequestStack;

class RegistrationHandler {

  protected $currentUser;

  /**
   * {@inheritdoc}
   */
  public function __construct(
    AccountInterface $current_user
  ) {
    $this->currentUser = $current_user;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('current_user')
    );
  }

  /**
   * Function to Register New User with OpenSign.
   */
  public function registerUser($signUpData) {
    if (!empty($signUpData)) {
      try {
        $config = \Drupal::config('opensign.server_settings');
        // Signup
        $headers = [
          'Content-Type' => 'application/json',
          'X-Parse-Application-Id' => $config->get('opensign_app_id'),
          'X-Parse-REST-API-Key' => $config->get('opensign_rest_api_key')
        ];
        $httpClient = new Client(['headers' => $headers]);

        $response = $httpClient->request('POST', $config->get('opensign_server_url') . '/users', [
          'form_params' => [
            'email' => $signUpData['opensign_email'],
            'name' => $signUpData['opensign_name'],
            'password' => $signUpData['opensign_password'],
            'phone' => $signUpData['opensign_phone'],
            'username' => $signUpData['opensign_email'],
          ]
        ]);

        $response_data = json_decode($response->getBody()->getContents(), TRUE);

        return [
          'status' => TRUE,
          'data' => $response_data
        ];
      } catch(Exception $e) {
        // Exception handling
        return [
          'status' => FALSE
        ];
      }
    }
  }
}
