<?php

namespace Drupal\opensign\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Password\PasswordInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\opensign\App\RegistrationHandler;
use Symfony\Component\DependencyInjection\ContainerInterface;

class RegistrationForm extends FormBase {

  /**
   * @var \Drupal\opensign\App\RegistrationHandler
   */
  protected $registrationHandler;

  protected $currentUser;

  protected $passwordHasher;

  /**
   * @param \Drupal\opensign\App\RegistrationHandler $registrationHandler
   */
  public function __construct(
    RegistrationHandler $registrationHandler,
    AccountInterface $current_user,
    PasswordInterface $password_hasher
  ) {
    $this->registrationHandler = $registrationHandler;
    $this->currentUser = $current_user;
    $this->passwordHasher = $password_hasher;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('opensign.registration_handler'),
      $container->get('current_user'),
      $container->get('password')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'opensign_registration_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = \Drupal::config('opensign.server_settings');

    $connection = \Drupal::service('database');

    $uid = $this->currentUser->id();
    $query = $connection->select('opensign_user', 'o')
      ->condition('o.uid', $uid, '=')
      ->fields('o', ['uid', 'opensign_email', 'opensign_password']);
    $result = $query->execute()->fetchAssoc();
    if (empty($result)) {
      $form['opensign_name'] = [
        '#type' => 'textfield',
        '#title' => t('Name'),
        '#required' => TRUE,
        '#disabled' => TRUE,
        '#value' => $this->currentUser->getAccountName()
      ];
      $form['opensign_email'] = [
        '#type' => 'email',
        '#title' => t('Email'),
        '#required' => TRUE,
        '#disabled' => TRUE,
        '#value' => $this->currentUser->getEmail()
      ];
      $form['opensign_phone'] = [
        '#type' => 'number',
        '#title' => t('Phone'),
      ];
      $form['opensign_password'] = [
        '#type' => 'password',
        '#title' => t('Password'),
        '#description' => t('Current Drupal Password'),
      ];
      $form['actions']['#type'] = 'actions';
      $form['actions']['submit'] = array(
        '#type' => 'submit',
        '#value' => $this->t('Register'),
        '#button_type' => 'primary',
      );
    } else {
      \Drupal::messenger()->addMessage("Current User is already Registered");
    }

    return $form;
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $uid = \Drupal::service('user.auth')->authenticate($values['opensign_name'], $values['opensign_password']);
    if (!empty($uid)) {
      $signUpData = [];
      $signUpData['opensign_name'] = $values['opensign_name'];
      $signUpData['opensign_email'] = $values['opensign_email'];
      $signUpData['opensign_phone'] = $values['opensign_phone'];
      $signUpData['opensign_password'] = md5($values['opensign_password']);

      $apiResult = $this->registrationHandler->registerUser($signUpData);
      if ($apiResult['status'] == FALSE) {
        \Drupal::messenger()->addError("User Register with OpenSign Failed");
      } else {
        // Register In Drupal Table;
        $connection = \Drupal::service('database');
        $result = $connection->insert('opensign_user')
          ->fields([
            'uid' => $uid,
            'opensign_name' => $signUpData['opensign_name'],
            'opensign_email' => $signUpData['opensign_email'],
            'opensign_phone' => $signUpData['opensign_phone'],
            'opensign_password' => $signUpData['opensign_password'],
          ])
        ->execute();
        \Drupal::messenger()->addMessage("User Register with OpenSign Successfully");
      }
    } else {
      \Drupal::messenger()->addError("Password is incorrect!!");
    }
  }

}